@@ -27,23 +27,43 @@ test_that("freq with NA and 'NA' is ok", {
 
 
 test_that("freq with sort, digits, cum, valid and total is correct", {
-  tab <- freq(hdv2003$qualif, digits = 2, cum = TRUE, total = TRUE, valid = FALSE, sort = "inc", na.last = FALSE)
+  tab <- freq(
+    hdv2003$qualif,
+    digits = 2,
+    cum = TRUE,
+    total = TRUE,
+    valid = FALSE,
+    sort = "inc",
+    na.last = FALSE
+  )
   v <- sort(summary(hdv2003$qualif))
   vnum <- as.numeric(v)
   expect_equal(names(tab), c("n", "%", "%cum"))
-  expect_equal(rownames(tab), gsub("NA's", "NA", c(names(v), "Total")))
+  expect_equal(rownames(tab), gsub("(NA's|NAs)", "NA", c(names(v), "Total")))
   expect_equal(tab$n, c(vnum, sum(vnum)))
   expect_equal(tab$`%`, c(round(vnum / sum(vnum) * 100, 2), 100))
   expect_equal(tab$`%cum`, c(round(cumsum(vnum) / sum(vnum) * 100, 2), 100))
 })
 
 test_that("freq with sort, digits, cum, valid, total and na.last is correct", {
-  tab <- freq(hdv2003$qualif, digits = 2, cum = TRUE, total = TRUE, valid = FALSE, sort = "inc", na.last = TRUE)
+  tab <- freq(
+    hdv2003$qualif,
+    digits = 2,
+    cum = TRUE,
+    total = TRUE,
+    valid = FALSE,
+    sort = "inc",
+    na.last = TRUE
+  )
   v <- sort(summary(hdv2003$qualif))
-  v <- c(v[names(v) != "NA's"], v[names(v) == "NA's"])
+  names(v) <- gsub("NA's|NAs", "NA", names(v))
+  v <- c(v[names(v) != "NA"], v[names(v) == "NA"])
   vnum <- as.numeric(v)
   expect_equal(names(tab), c("n", "%", "%cum"))
-  expect_equal(rownames(tab), gsub("NA's", "NA", c(names(v), "Total")))
+  expect_equal(
+    rownames(tab),
+    c(names(v), "Total")
+  )
   expect_equal(tab$n, c(vnum, sum(vnum)))
   expect_equal(tab$`%`, c(round(vnum / sum(vnum) * 100, 2), 100))
   expect_equal(tab$`%cum`, c(round(cumsum(vnum) / sum(vnum) * 100, 2), 100))
@@ -55,7 +75,10 @@ test_that("freq with exclude is correct", {
   v <- hdv2003$qualif[!(hdv2003$qualif %in% c(NA, "Cadre", "Autre"))]
   vtab <- as.numeric(table(v)[!(names(table(v)) %in% c(NA, "Cadre", "Autre"))])
   expect_equal(names(tab), c("n", "%"))
-  expect_equal(rownames(tab), setdiff(levels(hdv2003$qualif), c("NA", "Cadre", "Autre")))
+  expect_equal(
+    rownames(tab),
+    setdiff(levels(hdv2003$qualif), c("NA", "Cadre", "Autre"))
+  )
   expect_equal(tab$n, vtab)
   expect_equal(tab$`%`, round(vtab / sum(vtab) * 100, 1))
 })
@@ -64,8 +87,14 @@ test_that("cprop results are correct", {
   tab <- table(hdv2003$qualif, hdv2003$clso, exclude = NULL)
   etab <- tab[, apply(tab, 2, sum) > 0]
   ctab <- cprop(tab, n = TRUE)
-  expect_equal(colnames(ctab), c(levels(hdv2003$clso), gettext("All", domain = "R-questionr")))
-  expect_equal(rownames(ctab), c(levels(hdv2003$qualif), NA, gettext("Total", domain = "R-questionr"), "n"))
+  expect_equal(
+    colnames(ctab),
+    c(levels(hdv2003$clso), gettext("All", domain = "R-questionr"))
+  )
+  expect_equal(
+    rownames(ctab),
+    c(levels(hdv2003$qualif), NA, gettext("Total", domain = "R-questionr"), "n")
+  )
   m <- base::prop.table(etab, 2) * 100
   comp_tab <- ctab[seq_len(nrow(m)), seq_len(ncol(m))]
   # Manually set classes to fix failing tests during 4.5.0 -> 4.6.0
@@ -74,7 +103,13 @@ test_that("cprop results are correct", {
   expect_equal(comp_tab, m)
   margin <- margin.table(etab, 1)
   margin <- as.numeric(round(margin / sum(margin) * 100, 2))
-  expect_equal(unname(ctab[seq_len(length(margin)), gettext("All", domain = "R-questionr")]), margin)
+  expect_equal(
+    unname(ctab[
+      seq_len(length(margin)),
+      gettext("All", domain = "R-questionr")
+    ]),
+    margin
+  )
   n <- apply(etab, 2, sum)
   expect_equal(ctab["n", ][seq_len(length(n))], n)
 })
@@ -83,8 +118,14 @@ test_that("lprop results are correct", {
   tab <- table(hdv2003$qualif, hdv2003$clso, exclude = NULL)
   etab <- tab[, apply(tab, 2, sum) > 0]
   ltab <- lprop(tab, n = TRUE)
-  expect_equal(colnames(ltab), c(levels(hdv2003$clso), gettext("Total", domain = "R-questionr"), "n"))
-  expect_equal(rownames(ltab), c(levels(hdv2003$qualif), NA, gettext("All", domain = "R-questionr")))
+  expect_equal(
+    colnames(ltab),
+    c(levels(hdv2003$clso), gettext("Total", domain = "R-questionr"), "n")
+  )
+  expect_equal(
+    rownames(ltab),
+    c(levels(hdv2003$qualif), NA, gettext("All", domain = "R-questionr"))
+  )
   m <- base::prop.table(etab, 1) * 100
   comp_tab <- ltab[seq_len(nrow(m)), seq_len(ncol(m))]
   # Manually set classes to fix failing tests during 4.5.0 -> 4.6.0
@@ -93,7 +134,13 @@ test_that("lprop results are correct", {
   expect_equal(comp_tab, m)
   margin <- margin.table(etab, 2)
   margin <- as.numeric(round(margin / sum(margin) * 100, 2))
-  expect_equal(unname(ltab[gettext("All", domain = "R-questionr"), seq_len(length(margin))]), margin)
+  expect_equal(
+    unname(ltab[
+      gettext("All", domain = "R-questionr"),
+      seq_len(length(margin))
+    ]),
+    margin
+  )
   n <- apply(etab, 1, sum)
   expect_equal(ltab[, "n"][seq_len(length(n))], n)
 })
@@ -144,37 +191,45 @@ test_that("freqtable results are correct", {
   data(hdv2003)
   expect_error(freqtable(hdv2003))
   expect_error(freqtable(hdv2003, weights = poids))
-  expect_equal(freqtable(hdv2003, nivetud),
+  expect_equal(
+    freqtable(hdv2003, nivetud),
     xtabs(~nivetud, hdv2003, addNA = TRUE),
     check.attributes = FALSE
   )
-  expect_equal(freqtable(hdv2003, nivetud, sport),
+  expect_equal(
+    freqtable(hdv2003, nivetud, sport),
     xtabs(~ nivetud + sport, hdv2003, addNA = TRUE),
     check.attributes = FALSE
   )
-  expect_equal(freqtable(hdv2003, starts_with("niv")),
+  expect_equal(
+    freqtable(hdv2003, starts_with("niv")),
     xtabs(~nivetud, hdv2003, addNA = TRUE),
     check.attributes = FALSE
   )
 
-  expect_equal(freqtable(hdv2003, nivetud, na.rm = FALSE),
+  expect_equal(
+    freqtable(hdv2003, nivetud, na.rm = FALSE),
     xtabs(~nivetud, hdv2003, addNA = TRUE),
     check.attributes = FALSE
   )
-  expect_equal(freqtable(hdv2003, nivetud, na.rm = TRUE),
+  expect_equal(
+    freqtable(hdv2003, nivetud, na.rm = TRUE),
     xtabs(~nivetud, hdv2003),
     check.attributes = FALSE
   )
 
-  expect_equal(freqtable(hdv2003, nivetud, weights = poids),
+  expect_equal(
+    freqtable(hdv2003, nivetud, weights = poids),
     xtabs(poids ~ nivetud, hdv2003, addNA = TRUE),
     check.attributes = FALSE
   )
-  expect_equal(freqtable(hdv2003, nivetud, sport, weights = poids),
+  expect_equal(
+    freqtable(hdv2003, nivetud, sport, weights = poids),
     xtabs(poids ~ nivetud + sport, hdv2003, addNA = TRUE),
     check.attributes = FALSE
   )
-  expect_equal(freqtable(hdv2003, starts_with("niv"), weights = ends_with("oids")),
+  expect_equal(
+    freqtable(hdv2003, starts_with("niv"), weights = ends_with("oids")),
     xtabs(poids ~ nivetud, hdv2003, addNA = TRUE),
     check.attributes = FALSE
   )
@@ -182,35 +237,43 @@ test_that("freqtable results are correct", {
   skip_if_not_installed("survey")
   library(survey)
   hdv2003_wtd <- svydesign(ids = ~1, weights = ~poids, data = hdv2003)
-  expect_equal(freqtable(hdv2003_wtd, nivetud),
+  expect_equal(
+    freqtable(hdv2003_wtd, nivetud),
     xtabs(poids ~ nivetud, hdv2003, addNA = TRUE),
     check.attributes = FALSE
   )
-  expect_equal(freqtable(hdv2003_wtd, nivetud, sport),
+  expect_equal(
+    freqtable(hdv2003_wtd, nivetud, sport),
     xtabs(poids ~ nivetud + sport, hdv2003, addNA = TRUE),
     check.attributes = FALSE
   )
-  expect_equal(freqtable(hdv2003_wtd, nivetud, sport),
+  expect_equal(
+    freqtable(hdv2003_wtd, nivetud, sport),
     xtabs(poids ~ nivetud + sport, hdv2003, addNA = TRUE),
     check.attributes = FALSE
   )
-  expect_equal(freqtable(hdv2003_wtd, nivetud, weights = TRUE),
+  expect_equal(
+    freqtable(hdv2003_wtd, nivetud, weights = TRUE),
     xtabs(poids ~ nivetud, hdv2003, addNA = TRUE),
     check.attributes = FALSE
   )
-  expect_equal(freqtable(hdv2003_wtd, nivetud, weights = FALSE),
+  expect_equal(
+    freqtable(hdv2003_wtd, nivetud, weights = FALSE),
     xtabs(~nivetud, hdv2003, addNA = TRUE),
     check.attributes = FALSE
   )
-  expect_equal(freqtable(hdv2003_wtd, nivetud, weights = NULL),
+  expect_equal(
+    freqtable(hdv2003_wtd, nivetud, weights = NULL),
     xtabs(~nivetud, hdv2003, addNA = TRUE),
     check.attributes = FALSE
   )
-  expect_equal(freqtable(hdv2003_wtd, nivetud, weights = NULL, na.rm = FALSE),
+  expect_equal(
+    freqtable(hdv2003_wtd, nivetud, weights = NULL, na.rm = FALSE),
     xtabs(~nivetud, hdv2003, addNA = TRUE),
     check.attributes = FALSE
   )
-  expect_equal(freqtable(hdv2003_wtd, nivetud, weights = NULL, na.rm = TRUE),
+  expect_equal(
+    freqtable(hdv2003_wtd, nivetud, weights = NULL, na.rm = TRUE),
     xtabs(~nivetud, hdv2003),
     check.attributes = FALSE
   )
@@ -223,7 +286,7 @@ test_that("cprop, rprop and prop works with table of 3+ dimensions", {
   )
   expect_equal(
     t["2nd", "Male", "Adult", "Yes"] / 100,
-    Titanic["2nd", "Male", "Adult", "Yes"] / sum(Titanic[, , "Adult", "Yes"])
+    Titanic["2nd", "Male", "Adult", "Yes"] / sum(Titanic[,, "Adult", "Yes"])
   )
 
   expect_no_error(
@@ -231,7 +294,8 @@ test_that("cprop, rprop and prop works with table of 3+ dimensions", {
   )
   expect_equal(
     t["2nd", "Male", "Adult", "Yes"] / 100,
-    Titanic["2nd", "Male", "Adult", "Yes"] / sum(Titanic[, "Male", "Adult", "Yes"])
+    Titanic["2nd", "Male", "Adult", "Yes"] /
+      sum(Titanic[, "Male", "Adult", "Yes"])
   )
 
   expect_no_error(
@@ -239,7 +303,8 @@ test_that("cprop, rprop and prop works with table of 3+ dimensions", {
   )
   expect_equal(
     t["2nd", "Male", "Adult", "Yes"] / 100,
-    Titanic["2nd", "Male", "Adult", "Yes"] / sum(Titanic["2nd", , "Adult", "Yes"])
+    Titanic["2nd", "Male", "Adult", "Yes"] /
+      sum(Titanic["2nd", , "Adult", "Yes"])
   )
 
   expect_no_error(
